==> fluxcd-debug-2.7.5-1-x86_64.pkg.tar.zst: usr/src/debug/fluxcd/pkg/mod/github.com/fluxcd/go-git-providers@v0.25.0/gitlab/resource_pullrequest.go <==
/*
Copyright 2021 The Flux CD contributors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package gitlab

import (
	"github.com/fluxcd/go-git-providers/gitprovider"
	"gitlab.com/gitlab-org/api/client-go"
)

// The value of the "State" field of a gitlab merge request after it has been merged"
const mergedState = "merged"

func newPullRequest(ctx *clientContext, apiObj *gitlab.MergeRequest) *pullrequest {
	return &pullrequest{
		clientContext: ctx,
		pr:            *apiObj,
	}
}

var _ gitprovider.PullRequest = &pullrequest{}

type pullrequest struct {
	*clientContext

	pr gitlab.MergeRequest
}

func (pr *pullrequest) Get() gitprovider.PullRequestInfo {
	return pullrequestFromAPI(&pr.pr)
}

func (pr *pullrequest) APIObject() interface{} {
	return &pr.pr
}

func pullrequestFromAPI(apiObj *gitlab.MergeRequest) gitprovider.PullRequestInfo {
	return gitprovider.PullRequestInfo{
		Title:        apiObj.Title,
		Description:  apiObj.Description,
		Merged:       apiObj.State == mergedState,
		Number:       apiObj.IID,
		WebURL:       apiObj.WebURL,
		SourceBranch: apiObj.SourceBranch,
	}
}

==> fluxcd-debug-2.8.0-1-x86_64.pkg.tar.zst: usr/src/debug/fluxcd/pkg/mod/github.com/fluxcd/go-git-providers@v0.26.0/gitlab/resource_pullrequest.go <==
/*
Copyright 2021 The Flux CD contributors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package gitlab

import (
	"github.com/fluxcd/go-git-providers/gitprovider"
	gitlab "gitlab.com/gitlab-org/api/client-go"
)

// The value of the "State" field of a gitlab merge request after it has been merged"
const mergedState = "merged"

func newPullRequest(ctx *clientContext, apiObj *gitlab.MergeRequest) *pullrequest {
	return &pullrequest{
		clientContext: ctx,
		pr:            *apiObj,
	}
}

var _ gitprovider.PullRequest = &pullrequest{}

type pullrequest struct {
	*clientContext

	pr gitlab.MergeRequest
}

func (pr *pullrequest) Get() gitprovider.PullRequestInfo {
	return pullrequestFromAPI(&pr.pr)
}

func (pr *pullrequest) APIObject() interface{} {
	return &pr.pr
}

func pullrequestFromAPI(apiObj *gitlab.MergeRequest) gitprovider.PullRequestInfo {
	return gitprovider.PullRequestInfo{
		Title:        apiObj.Title,
		Description:  apiObj.Description,
		Merged:       apiObj.State == mergedState,
		Number:       int(apiObj.IID),
		WebURL:       apiObj.WebURL,
		SourceBranch: apiObj.SourceBranch,
	}
}
